solstice-config
============================================================

Solstice Module that contains project-specific configuration files

.. image:: https://travis-ci.com/ArtellaPipe/solstice-config.svg?branch=master&kill_cache=1
    :target: https://travis-ci.com/Solstice-Short-Film/solstice-config

.. image:: https://coveralls.io/repos/github/Solstice-Short-Film/solstice-config/badge.svg?branch=master&kill_cache=1
    :target: https://coveralls.io/github/Solstice-Short-Film/solstice-config?branch=master

.. image:: https://img.shields.io/github/license/Solstice-Short-Film/solstice-config
    :target: https://github.com/Solstice-Short-Film/solstice-config/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/solstice-config?branch=master&kill_cache=1
    :target: https://pypi.org/project/solstice-config/

.. image:: https://img.shields.io/badge/code_style-pep8-blue
    :target: https://www.python.org/dev/peps/pep-0008/